==> haskell-x11-1.9.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11
version: 1.9.1
id: X11-1.9.1-5h83ZF5j2HeIIVKyFog1c8
key: X11-1.9.1-5h83ZF5j2HeIIVKyFog1c8
license: BSD-3-Clause
copyright: Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007,
           Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.
maintainer: Daniel Wagner <daniel@wagner-home.com>
homepage: https://github.com/xmonad/X11
synopsis: A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library. The binding is a direct
    translation of the C binding; for documentation of these calls, refer
    to \"The Xlib Programming Manual\", available online at
    <http://tronche.com/gui/x/xlib/>.
category: Graphics
abi: 383a95f66b9debd77cfd27cb58f6f976
exposed: True
exposed-modules:
    Graphics.X11 Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault Graphics.X11.Types
    Graphics.X11.XScreenSaver Graphics.X11.Xinerama Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Extras Graphics.X11.Xlib.Font
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xrandr
hidden-modules: Graphics.X11.Xlib.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/X11-1.9.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/X11-1.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/X11-1.9.1
hs-libraries: HSX11-1.9.1-5h83ZF5j2HeIIVKyFog1c8
extra-libraries:
    Xss Xinerama Xext X11 Xrandr Xext
include-dirs: /usr/lib/ghc-8.6.5/site-local/X11-1.9.1/include
includes:
    HsXlib.h HsAllKeysyms.h
depends:
    base-4.12.0.0 data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces: /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html: /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-1.9.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11
version: 1.9.1
id: X11-1.9.1-DDpoyt98FZwLP1A4hYmqcn
key: X11-1.9.1-DDpoyt98FZwLP1A4hYmqcn
license: BSD-3-Clause
copyright: Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007,
           Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.
maintainer: Daniel Wagner <daniel@wagner-home.com>
homepage: https://github.com/xmonad/X11
synopsis: A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library. The binding is a direct
    translation of the C binding; for documentation of these calls, refer
    to \"The Xlib Programming Manual\", available online at
    <http://tronche.com/gui/x/xlib/>.
category: Graphics
abi: 943b5aca6da282727208366708c636ff
exposed: True
exposed-modules:
    Graphics.X11 Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault Graphics.X11.Types
    Graphics.X11.XScreenSaver Graphics.X11.Xinerama Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Extras Graphics.X11.Xlib.Font
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xrandr
hidden-modules: Graphics.X11.Xlib.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/X11-1.9.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/X11-1.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/X11-1.9.1
hs-libraries: HSX11-1.9.1-DDpoyt98FZwLP1A4hYmqcn
extra-libraries:
    Xss Xinerama Xext X11 Xrandr Xext
include-dirs: /usr/lib/ghc-8.6.5/site-local/X11-1.9.1/include
includes:
    HsXlib.h HsAllKeysyms.h
depends:
    base-4.12.0.0 data-default-0.7.1.1-BJebZgJOe7bK46yzXrFmEt
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces: /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html: /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
